'use client'

import React, { useState } from 'react'
import WalletHeader from '../components/WalletHeader'
import AIServiceCard from '../components/AIServiceCard'
import { generateChatResponse, ChatGenerationResult, CHAT_MODELS } from '../services/chatService'
import { processMTMPayment } from '../services/paymentService'
import { connectWallet, WalletState } from '../services/walletService'
import { WalletType } from '../services/types'

const Page: React.FC = (): React.ReactElement => {
  const [walletState, setWalletState] = useState<WalletState>({
    connected: false,
    publicKey: null,
    type: null
  })

const handleConnect = async (walletType: WalletType): Promise<void> => {
    try {
      const newWalletState = await connectWallet(walletType)
      setWalletState(newWalletState)
    } catch (error) {
      console.error('Wallet connection error:', error)
      setWalletState({
        connected: false,
        publicKey: null,
        type: null
      })
    }
  }

  const handleChatGeneration = (modelId: string, cost: number) => {
    return async (prompt: string): Promise<ChatGenerationResult> => {
      if (!walletState.connected || !walletState.publicKey) {
        return { error: 'Wallet not connected' }
      }

      // Process payment first
      const paymentResult = await processMTMPayment(
        walletState.publicKey,
        cost,
        walletState.type
      )

      if (!paymentResult.success) {
        return { error: paymentResult.error }
      }

      // Then generate chat response with specified model
      return generateChatResponse(prompt, modelId)
    }
  }

  return (
    <div className="min-h-screen w-full flex flex-col items-center bg-gradient-to-b from-slate-950 via-orange-950 to-slate-950">
      <div className="container max-w-7xl mx-auto px-4 py-8">
        {/* Header */}
        <div className="text-center mb-8">
          <h1 className="text-4xl sm:text-5xl font-bold mb-4 text-transparent bg-clip-text bg-gradient-to-r from-orange-400 to-amber-500">
            Mark's Mama Market
          </h1>
          <p className="text-orange-200 text-lg mb-8">
            Ask each of Mark's grandmas for advice
          </p>
          
          <WalletHeader
          walletState={walletState}
            onConnect={handleConnect}
	  />
        </div>

        {/* Chat Models Grid */}
	        <div className="grid grid-cols-1 md:grid-cols-2 xl:grid-cols-3 gap-6">
          {CHAT_MODELS.map((model) => (
            <AIServiceCard
              key={model.characterId}
              title={model.name}
              description={model.description}
              tokenCost={model.cost}
              isWalletConnected={walletState.connected}
              onGenerate={handleChatGeneration(model.characterId, model.cost)}
            />

          ))}
          
          {/* Coming Soon Card */}
          <div className="relative bg-purple-900/30 backdrop-blur-lg rounded-2xl shadow-xl border border-purple-700/50 overflow-hidden group hover:shadow-purple-500/20 transition-all duration-300">
            <div className="absolute inset-0 bg-gradient-to-br from-purple-600/10 to-pink-500/10 opacity-50"></div>
            <div className="relative p-6 flex flex-col h-full">
              <div className="flex-1">
                <h3 className="text-2xl font-bold text-transparent bg-clip-text bg-gradient-to-r from-purple-400 to-pink-500">
                  More Grandmas Soon
                </h3>
                <p className="mt-2 text-purple-200">
                  New grandmothers in development, stay tuned!
                </p>
                <div className="mt-2 inline-block px-3 py-1 bg-purple-500/20 rounded-full">
                  <span className="text-purple-200 text-sm">TBD</span>
                </div>
              </div>
              
              <div className="mt-6">
                <button
                  disabled
                  className="w-full bg-gradient-to-r from-purple-500/50 to-pink-500/50 
                           text-white/50 font-semibold py-4 px-6 rounded-xl 
                           cursor-not-allowed opacity-50"
                >
                  Coming Soon
                </button>
              </div>
            </div>
          </div>
        </div>

        {/* Info Section */}
        <div className="mt-12 text-center text-slate-400">
          <p className="text-sm">
            Powered by Mark • Use at your own risk
          </p>
        </div>
      </div>
    </div>
  )
}

export default Page
