'use client'

import React, { useState } from 'react'

interface AIServiceCardProps {
  title: string
  description: string
  tokenCost: number
  isWalletConnected: boolean
  onGenerate: (prompt: string) => Promise<{ response?: string, error?: string }>
}

interface GenerationState {
  loading: boolean
  response: string | null
  error: string | null
}

const AIServiceCard: React.FC<AIServiceCardProps> = ({
  title,
  description,
  tokenCost,
  isWalletConnected,
  onGenerate
}) => {
  const [inputText, setInputText] = useState<string>('')
  const [generationState, setGenerationState] = useState<GenerationState>({
    loading: false,
    response: null,
    error: null,
  })

  const handleGenerate = async (): Promise<void> => {
    if (!inputText || !isWalletConnected) return

    setGenerationState({
      ...generationState,
      loading: true,
      error: null,
    })

    try {
      const result = await onGenerate(inputText)
      
      if (result.error) {
        setGenerationState({
          ...generationState,
          loading: false,
          error: result.error,
        })
        return
      }

      if (result.response) {
        setGenerationState({
          loading: false,
          response: result.response,
          error: null,
        })
      } else {
        throw new Error('No response received')
      }
    } catch (error) {
      setGenerationState({
        ...generationState,
        loading: false,
        error: error instanceof Error ? error.message : 'Generation failed',
      })
    }
  }

  return (
    <div className="w-full bg-slate-900/50 backdrop-blur-lg rounded-2xl shadow-xl border border-orange-800/50 mb-8 hover:shadow-orange-500/20 transition-all duration-300">
      <div className="p-6">
        <div className="mb-4">
          <h2 className="text-2xl font-bold text-transparent bg-clip-text bg-gradient-to-r from-orange-400 to-amber-500">
            {title}
          </h2>
          <p className="text-slate-300 mt-2">{description}</p>
          <div className="mt-2 inline-block px-3 py-1 bg-amber-500/20 rounded-full text-amber-200 text-sm">
            Cost: {tokenCost} MTM
          </div>
        </div>

        <div className="space-y-4">
          <textarea
            value={inputText}
            onChange={(e) => setInputText(e.target.value)}
            placeholder="Ask me anything..."
            disabled={!isWalletConnected}
            className="w-full bg-slate-950/80 text-slate-200 border border-orange-900 rounded-xl p-4 
                     placeholder-slate-500 focus:border-amber-500 focus:ring-2 focus:ring-amber-500/20 
                     focus:outline-none min-h-[120px] transition-all duration-200
                     disabled:opacity-50 disabled:cursor-not-allowed"
            rows={4}
          />
          <button
            onClick={handleGenerate}
            disabled={!isWalletConnected || generationState.loading || !inputText}
            className="w-full bg-gradient-to-r from-orange-500 to-amber-500 hover:from-orange-600 
                     hover:to-amber-600 text-white font-semibold py-4 px-6 rounded-xl 
                     transition-all duration-200 shadow-lg hover:shadow-amber-500/25 
                     disabled:opacity-50 disabled:cursor-not-allowed disabled:hover:shadow-none"
          >
            {generationState.loading ? 'Processing...' : `Pay ${tokenCost} MTM & Chat`}
          </button>
        </div>

        {generationState.error && (
          <div className="mt-4 bg-red-900/20 border border-red-500/20 text-red-400 px-4 py-3 rounded-xl text-center">
            {generationState.error}
          </div>
        )}

        {generationState.response && (
          <div className="mt-4 bg-slate-800/50 border border-orange-800/50 rounded-xl p-4">
            <p className="text-slate-200 whitespace-pre-wrap">{generationState.response}</p>
          </div>
        )}
      </div>
    </div>
  )
}

export default AIServiceCard
